@@ -11,7 +11,7 @@ fusedlasso2d <- function(y, X, dim1, dim2, gamma=0, approx=FALSE,
                          maxsteps=2000, minlam=0, tol=1e-11, verbose=FALSE,
                          fileback=FALSE) {
   if (missing(y)) stop("y is missing.")
-  if (!is.numeric(y) && !is.matrix(y)) stop("y must be numeric (if X is missing, then y can alternatively be a matrix).")
+  if (!is.numeric(y)) stop("y must be numeric.")
   if (length(y) == 0) stop("There must be at least one data point [must have length(y) > 1].")
   if (missing(X)) X = NULL
   if (missing(dim1) || missing(dim2)) {
@@ -32,10 +32,8 @@ fusedlasso2d <- function(y, X, dim1, dim2, gamma=0, approx=FALSE,
   if (!is.null(X) && ncol(X)!=dim1*dim2) {
     stop("Dimensions don't match [ncol(X) != dim1*dim2].")
   }
-  
-  y = as.numeric(y)
-  D = getD2dSparse(dim1,dim2)
 
+  D = getD2dSparse(dim1,dim2)
   out = fusedlasso(y,X,D,NULL,gamma,approx,maxsteps,minlam,tol,verbose,fileback)
   out$call = match.call()
   
